rename threads.h -> threads-model.h
[c11tester.git] / main.cc
diff --git a/main.cc b/main.cc
index 26d8beb79d52f8d09a9d16b97f96c79972941822..bff111f09dc28a99eff0ff2b70b4526141f39737 100644 (file)
--- a/main.cc
+++ b/main.cc
@@ -6,7 +6,7 @@
 
 #include "libthreads.h"
 #include "common.h"
-#include "threads.h"
+#include "threads-model.h"
 
 #include "datarace.h"
 
@@ -77,8 +77,14 @@ static void parse_options(struct model_params *params, int *argc, char ***argv)
 int main_argc;
 char **main_argv;
 
-/** The real_main function contains the main model checking loop. */
-static void real_main() {
+/** Wrapper to run the user's main function, with appropriate arguments */
+void wrapper_user_main(void *)
+{
+       user_main(main_argc, main_argv);
+}
+
+/** The model_main function contains the main model checking loop. */
+static void model_main() {
        thrd_t user_thread;
        struct model_params params;
 
@@ -97,7 +103,7 @@ static void real_main() {
        snapshotObject->snapshotStep(0);
        do {
                /* Start user program */
-               model->add_thread(new Thread(&user_thread, (void (*)(void *)) &user_main, NULL));
+               model->add_thread(new Thread(&user_thread, &wrapper_user_main, NULL));
 
                /* Wait for all threads to complete */
                model->finish_execution();
@@ -110,12 +116,12 @@ static void real_main() {
 
 /**
  * Main function.  Just initializes snapshotting library and the
* snapshotting library calls the real_main function.
  */
 int main(int argc, char ** argv) {
        main_argc = argc;
        main_argv = argv;
 
        /* Let's jump in quickly and start running stuff */
-       initSnapShotLibrary(10000, 1024, 1024, 1000, &real_main);
+       initSnapshotLibrary(10000, 1024, 1024, 4000, &model_main);
 }
@@ -110,12 +116,12 @@ static void real_main() {
 /**
  * Main function.  Just initializes snapshotting library and the
- * snapshotting library calls the real_main function.
+ * snapshotting library calls the model_main function.
  */
 int main(int argc, char ** argv) {